==> xpi-forecastfox-0.9.8.tbz: lib/xpi/{0538E3E3-7E9B-4d49-8831-A227C80A7AD3}/defaults/converters.js <==
({
  "degrees-0-none": {name: "none", conversion: "degrees", units: 0, format: "$CALC + String.fromCharCode(176);", calc: "Number($VAL)"},  
  "degrees-1-none": {name: "none", conversion: "degrees", units: 0, format: "$CALC + String.fromCharCode(176);", calc: "Number($VAL)" },    
  "percent-0-none": {name: "none", conversion: "percent", units: 0, format: "$CALC + String.fromCharCode(37);", calc: "Number($VAL)"},  
  "percent-1-none": {name: "none", conversion: "percent", units: 1, format: "$CALC + String.fromCharCode(37);", calc: "Number($VAL)"}, 
  "pressure-0-none": {name: "none", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "in"},    
  "pressure-0-in": {name: "none", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "in"},    
  "pressure-0-psi": {name: "psi", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.491130).toFixed(2)", abbr: "in"},  
  "pressure-0-atm": {name: "atm", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.033421).toFixed(2)", abbr: "atm"},  
  "pressure-0-mb": {name: "mb", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 33.8639).toFixed(2)", abbr: "mb"},
  "pressure-0-mm": {name: "mm", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 25.4).toFixed(2)", abbr: "mm"},
  "pressure-0-hpa": {name: "hpa", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 33.8639).toFixed(2)", abbr: "hPa"},
  "pressure-0-kpa": {name: "kpa", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "((Number($VAL)/10) * 3.38639).toFixed(2)", abbr: "kPa"},   
  "pressure-1-none": {name: "none", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mb"},    
  "pressure-1-in": {name: "in", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.0295300).toFixed(2)", abbr: "in"},  
  "pressure-1-psi": {name: "psi", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.0145038).toFixed(2)", abbr: "psi"},
  "pressure-1-atm": {name: "atm", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.0009869233).toFixed(2)", abbr: "atm"},    
  "pressure-1-mb": {name: "none", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mb"},    
  "pressure-1-mm": {name: "mm", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.750062).toFixed(2)", abbr: "mm"},        
  "pressure-1-hpa": {name: "hpa", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "hPa"},     
  "pressure-1-kpa": {name: "kpa", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) / 10).toFixed(2)", abbr: "kPa"},     
  "temp-0-none": {name: "none", conversion: "temp", units: 0, format: "$CALC + String.fromCharCode(176) + ' $ABBR';", calc: "Number($VAL)", abbr: "F"},     
  "temp-0-short": {name: "short", conversion: "temp", units: 0, format: "$CALC + String.fromCharCode(176);", calc: "Number($VAL)"},         
  "temp-0-f": {name: "none", conversion: "temp", units: 0, format: "$CALC + String.fromCharCode(176) + ' $ABBR';", calc: "Number($VAL)", abbr: "F"},     
  "temp-0-c": {name: "c", conversion: "temp", units: 0, format: "$CALC + String.fromCharCode(176) + ' $ABBR';", calc: "Math.round((Number($VAL) - 32)/1.8)", abbr: "C"},     
  "temp-0-k": {name: "k", conversion: "temp", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round((Number($VAL) - 32)/1.8 + 273.15)", abbr: "K"},    
  "temp-0-r": {name: "r", conversion: "temp", units: 0, format: "$CALC + String.fromCharCode(176) + ' $ABBR';", calc: "Math.round(Number($VAL) - 459.69)", abbr: "R"},        
  "temp-1-none": {name: "none", conversion: "temp", units: 1, format: "$CALC + String.fromCharCode(176) + ' $ABBR';", calc: "Number($VAL)", abbr: "C"},     
  "temp-1-short": {name: "short", conversion: "temp", units: 1, format: "$CALC + String.fromCharCode(176);", calc: "Number($VAL)"},        
  "temp-1-f": {name: "f", conversion: "temp", units: 1, format: "$CALC + String.fromCharCode(176) + ' $ABBR';", calc: "Math.round(Number($VAL)*1.8 + 32)", abbr: "F"},     
  "temp-1-c": {name: "none", conversion: "temp", units: 1, format: "$CALC + String.fromCharCode(176) + ' $ABBR';", calc: "Number($VAL)", abbr: "C"},     
  "temp-1-k": {name: "k", conversion: "temp", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) + 273.15)", abbr: "K"},     
  "temp-1-r": {name: "r", conversion: "temp", units: 1, format: "$CALC + String.fromCharCode(176) + ' $ABBR';", calc: "Math.round((Number($VAL)*1.8 + 32) + 459.69)", abbr: "R"},       
  "speed-0-none": {name: "none", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mph"},     
  "speed-0-fts": {name: "fts", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 1.46667)", abbr: "ft/s"}, 
  "speed-0-mph": {name: "none", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mph"},     
  "speed-0-ms": {name: "ms", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 0.44704)", abbr: "m/s"},     
  "speed-0-kmh": {name: "kmh", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 1.609344)", abbr: "km/h"},    
  "speed-0-kn": {name: "kn", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 0.868391)", abbr: "kn"},    
  "speed-0-bft": {name: "bft", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round(Math.pow(((Number($VAL) * 0.44704) * 1.1947),(2/3)))", abbr: "Bft"},     
  "speed-1-none": {name: "none", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "m/s"},    
  "speed-1-fts": {name: "fts", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 3.28084)", abbr: "ft/s"},    
  "speed-1-mph": {name: "mph", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 2.23694)", abbr: "mph"},      
  "speed-1-ms": {name: "none", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "m/s"},    
  "speed-1-kmh": {name: "kmh", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 3.6)", abbr: "km/h"},    
  "speed-1-kn": {name: "kn", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 1.94254)", abbr: "kn"},   
  "speed-1-bft": {name: "bft", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Math.pow((Number($VAL) * 1.1947),(2/3)))", abbr: "Bft"},   
  "dist-0-none": {name: "none", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mi"},   
  "dist-0-ft": {name: "ft", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 5280).toFixed(2)", abbr: "ft"},  
  "dist-0-yds": {name: "yds", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 1760).toFixed(2)", abbr: "yds"},   
  "dist-0-mi": {name: "none", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mi"},   
  "dist-0-m": {name: "m", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 1609.344).toFixed(2)", abbr: "m"},   
  "dist-0-km": {name: "km", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 1.609344).toFixed(2)", abbr: "km"}, 
  "dist-0-fth": {name: "fth", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 879.99824).toFixed(2)", abbr: "fth"},   
  "dist-0-lea": {name: "lea", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.33333267).toFixed(2)", abbr: "lea"},   
  "dist-0-nm": {name: "nm", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.86897624).toFixed(2)", abbr: "nm"},   
  "dist-1-none": {name: "none", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "km"}, 
  "dist-1-ft": {name: "ft", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 3280.8399).toFixed(2)", abbr: "ft"},      
  "dist-1-yds": {name: "yds", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 1093.6133).toFixed(2)", abbr: "yds"},    
  "dist-1-mi": {name: "mi", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.621371192).toFixed(2)", abbr: "mi"},    
  "dist-1-m": {name: "m", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 1000).toFixed(2)", abbr: "m"}, 
  "dist-1-km": {name: "none", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "km"}, 
  "dist-1-fth": {name: "fth", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 546.80556).toFixed(2)", abbr: "fth"},  
  "dist-1-lea": {name: "lea", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.20712332).toFixed(2)", abbr: "lea"},   
  "dist-1-nm": {name: "nm", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.5399568).toFixed(2)", abbr: "nm"},
  "precip-0-none": {name: "none", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "in"}, 
  "precip-0-in": {name: "none", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "in"}, 
  "precip-0-ft": {name: "ft", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.083333333).toFixed(2)", abbr: "ft"},     
  "precip-0-yds": {name: "yds", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.027777778).toFixed(2)", abbr: "yds"}, 
  "precip-0-mm": {name: "mm", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 25.4).toFixed(2)", abbr: "mm"}, 
  "precip-0-cm": {name: "cm", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 2.54).toFixed(2)", abbr: "cm"},
  "precip-0-m": {name: "m", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * .0254).toFixed(2)", abbr: "m"},   
  "precip-1-none": {name: "none", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "cm"},
  "precip-1-in": {name: "in", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.39370079).toFixed(2)", abbr: "in"}, 
  "precip-1-ft": {name: "ft", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.032808399).toFixed(2)", abbr: "ft"},
  "precip-1-yds": {name: "yds", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.010936133).toFixed(2)", abbr: "yds"},
  "precip-1-mm": {name: "mm", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 10).toFixed(2)", abbr: "mm"},
  "precip-1-cm": {name: "none", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "cm"},
  "precip-1-m": {name: "m", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.01).toFixed(2)", abbr: "m"}
 });

==> xpi-forecastfox-0.9.10.2.tbz: lib/xpi/{0538E3E3-7E9B-4d49-8831-A227C80A7AD3}/defaults/converters.js <==
({
  "degrees-0-none": {name: "none", conversion: "degrees", units: 0, format: "$CALC + String.fromCharCode(176);", calc: "Number($VAL)"},  
  "degrees-1-none": {name: "none", conversion: "degrees", units: 0, format: "$CALC + String.fromCharCode(176);", calc: "Number($VAL)" },    
  "percent-0-none": {name: "none", conversion: "percent", units: 0, format: "$CALC + String.fromCharCode(37);", calc: "Number($VAL)"},  
  "percent-1-none": {name: "none", conversion: "percent", units: 1, format: "$CALC + String.fromCharCode(37);", calc: "Number($VAL)"}, 
  "pressure-0-none": {name: "none", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "in"},    
  "pressure-0-in": {name: "none", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "in"},    
  "pressure-0-psi": {name: "psi", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.491130).toFixed(2)", abbr: "in"},  
  "pressure-0-atm": {name: "atm", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.033421).toFixed(2)", abbr: "atm"},  
  "pressure-0-mb": {name: "mb", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 33.8639).toFixed(2)", abbr: "mb"},
  "pressure-0-mm": {name: "mm", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 25.4).toFixed(2)", abbr: "mm"},
  "pressure-0-hpa": {name: "hpa", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 33.8639).toFixed(2)", abbr: "hPa"},
  "pressure-0-kpa": {name: "kpa", conversion: "pressure", units: 0, format: "$CALC + ' $ABBR';", calc: "((Number($VAL)/10) * 3.38639).toFixed(2)", abbr: "kPa"},   
  "pressure-1-none": {name: "none", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mb"},    
  "pressure-1-in": {name: "in", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.0295300).toFixed(2)", abbr: "in"},  
  "pressure-1-psi": {name: "psi", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.0145038).toFixed(2)", abbr: "psi"},
  "pressure-1-atm": {name: "atm", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.0009869233).toFixed(2)", abbr: "atm"},    
  "pressure-1-mb": {name: "none", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mb"},    
  "pressure-1-mm": {name: "mm", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.750062).toFixed(2)", abbr: "mm"},        
  "pressure-1-hpa": {name: "hpa", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "hPa"},     
  "pressure-1-kpa": {name: "kpa", conversion: "pressure", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) / 10).toFixed(2)", abbr: "kPa"},     
  "temp-0-none": {name: "none", conversion: "temp", units: 0, format: "$CALC + ' ' + String.fromCharCode(176) + '$ABBR';", calc: "Number($VAL)", abbr: "F"},     
  "temp-0-short": {name: "short", conversion: "temp", units: 0, format: "$CALC + String.fromCharCode(176);", calc: "Number($VAL)"},         
  "temp-0-f": {name: "none", conversion: "temp", units: 0, format: "$CALC + ' ' + String.fromCharCode(176) + '$ABBR';", calc: "Number($VAL)", abbr: "F"},     
  "temp-0-c": {name: "c", conversion: "temp", units: 0, format: "$CALC + ' ' + String.fromCharCode(176) + '$ABBR';", calc: "Math.round((Number($VAL) - 32)/1.8)", abbr: "C"},     
  "temp-0-k": {name: "k", conversion: "temp", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round((Number($VAL) - 32)/1.8 + 273.15)", abbr: "K"},    
  "temp-0-r": {name: "r", conversion: "temp", units: 0, format: "$CALC + ' ' + String.fromCharCode(176) + '$ABBR';", calc: "Math.round(Number($VAL) - 459.69)", abbr: "R"},        
  "temp-1-none": {name: "none", conversion: "temp", units: 1, format: "$CALC + ' ' + String.fromCharCode(176) + '$ABBR';", calc: "Number($VAL)", abbr: "C"},     
  "temp-1-short": {name: "short", conversion: "temp", units: 1, format: "$CALC + String.fromCharCode(176);", calc: "Number($VAL)"},        
  "temp-1-f": {name: "f", conversion: "temp", units: 1, format: "$CALC + ' ' + String.fromCharCode(176) + '$ABBR';", calc: "Math.round(Number($VAL)*1.8 + 32)", abbr: "F"},     
  "temp-1-c": {name: "none", conversion: "temp", units: 1, format: "$CALC + ' ' + String.fromCharCode(176) + '$ABBR';", calc: "Number($VAL)", abbr: "C"},     
  "temp-1-k": {name: "k", conversion: "temp", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) + 273.15)", abbr: "K"},     
  "temp-1-r": {name: "r", conversion: "temp", units: 1, format: "$CALC + ' ' + String.fromCharCode(176) + '$ABBR';", calc: "Math.round((Number($VAL)*1.8 + 32) + 459.69)", abbr: "R"},       
  "speed-0-none": {name: "none", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mph"},     
  "speed-0-fts": {name: "fts", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 1.46667)", abbr: "ft/s"}, 
  "speed-0-mph": {name: "none", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mph"},     
  "speed-0-ms": {name: "ms", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 0.44704)", abbr: "m/s"},     
  "speed-0-kmh": {name: "kmh", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 1.609344)", abbr: "km/h"},    
  "speed-0-kn": {name: "kn", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 0.868391)", abbr: "kn"},    
  "speed-0-bft": {name: "bft", conversion: "speed", units: 0, format: "$CALC + ' $ABBR';", calc: "Math.round(Math.pow(((Number($VAL) * 0.44704) * 1.1947),(2/3)))", abbr: "Bft"},     
  "speed-1-none": {name: "none", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "m/s"},    
  "speed-1-fts": {name: "fts", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 3.28084)", abbr: "ft/s"},    
  "speed-1-mph": {name: "mph", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 2.23694)", abbr: "mph"},      
  "speed-1-ms": {name: "none", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "m/s"},    
  "speed-1-kmh": {name: "kmh", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 3.6)", abbr: "km/h"},    
  "speed-1-kn": {name: "kn", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Number($VAL) * 1.94254)", abbr: "kn"},   
  "speed-1-bft": {name: "bft", conversion: "speed", units: 1, format: "$CALC + ' $ABBR';", calc: "Math.round(Math.pow((Number($VAL) * 1.1947),(2/3)))", abbr: "Bft"},   
  "dist-0-none": {name: "none", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mi"},   
  "dist-0-ft": {name: "ft", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 5280).toFixed(2)", abbr: "ft"},  
  "dist-0-yds": {name: "yds", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 1760).toFixed(2)", abbr: "yds"},   
  "dist-0-mi": {name: "none", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "mi"},   
  "dist-0-m": {name: "m", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 1609.344).toFixed(2)", abbr: "m"},   
  "dist-0-km": {name: "km", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 1.609344).toFixed(2)", abbr: "km"}, 
  "dist-0-fth": {name: "fth", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 879.99824).toFixed(2)", abbr: "fth"},   
  "dist-0-lea": {name: "lea", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.33333267).toFixed(2)", abbr: "lea"},   
  "dist-0-nm": {name: "nm", conversion: "dist", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.86897624).toFixed(2)", abbr: "nm"},   
  "dist-1-none": {name: "none", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "km"}, 
  "dist-1-ft": {name: "ft", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 3280.8399).toFixed(2)", abbr: "ft"},      
  "dist-1-yds": {name: "yds", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 1093.6133).toFixed(2)", abbr: "yds"},    
  "dist-1-mi": {name: "mi", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.621371192).toFixed(2)", abbr: "mi"},    
  "dist-1-m": {name: "m", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 1000).toFixed(2)", abbr: "m"}, 
  "dist-1-km": {name: "none", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "km"}, 
  "dist-1-fth": {name: "fth", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 546.80556).toFixed(2)", abbr: "fth"},  
  "dist-1-lea": {name: "lea", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.20712332).toFixed(2)", abbr: "lea"},   
  "dist-1-nm": {name: "nm", conversion: "dist", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.5399568).toFixed(2)", abbr: "nm"},
  "precip-0-none": {name: "none", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "in"}, 
  "precip-0-in": {name: "none", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "in"}, 
  "precip-0-ft": {name: "ft", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.083333333).toFixed(2)", abbr: "ft"},     
  "precip-0-yds": {name: "yds", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.027777778).toFixed(2)", abbr: "yds"}, 
  "precip-0-mm": {name: "mm", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 25.4).toFixed(2)", abbr: "mm"}, 
  "precip-0-cm": {name: "cm", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 2.54).toFixed(2)", abbr: "cm"},
  "precip-0-m": {name: "m", conversion: "precip", units: 0, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * .0254).toFixed(2)", abbr: "m"},   
  "precip-1-none": {name: "none", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "cm"},
  "precip-1-in": {name: "in", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.39370079).toFixed(2)", abbr: "in"}, 
  "precip-1-ft": {name: "ft", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.032808399).toFixed(2)", abbr: "ft"},
  "precip-1-yds": {name: "yds", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.010936133).toFixed(2)", abbr: "yds"},
  "precip-1-mm": {name: "mm", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 10).toFixed(2)", abbr: "mm"},
  "precip-1-cm": {name: "none", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "Number($VAL)", abbr: "cm"},
  "precip-1-m": {name: "m", conversion: "precip", units: 1, format: "$CALC + ' $ABBR';", calc: "(Number($VAL) * 0.01).toFixed(2)", abbr: "m"}
 });
